flags

package
v0.16.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 12, 2023 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

const (
	// ServerURL available in the CLI context
	ServerURL = "server-url"
	// JobToken available in the CLI context
	JobToken = "job-token"
	// PrivateToken available in the CLI context
	PrivateToken = "private-token"
	// ProjectID available in the CLI context
	ProjectID = "project-id"
	// Timeout available in the CLI context
	Timeout = "timeout"
	// Name available in the CLI context
	Name = "name"
	// Description available in the CLI context
	Description = "description"
	// TagName available in the CLI context
	TagName = "tag-name"
	// TagMessage available in the CLI context
	TagMessage = "tag-message"
	// Ref available in the CLI context
	Ref = "ref"
	// AssetsLink available in the CLI context
	AssetsLink = "assets-link"
	// Milestone available in the CLI context
	Milestone = "milestone"
	// ReleasedAt available in the CLI context
	ReleasedAt = "released-at"
	// Debug available in the CLI context
	Debug = "debug"
	// File available in the CLI context
	File = "file"
	// AdditionalCACertBundle available in the CLI context
	AdditionalCACertBundle = "additional-ca-cert-bundle"
	// InsecureHTTPS flag available in the CLI context
	InsecureHTTPS = "insecure-https"
	// IncludeHTMLDescription flag
	IncludeHTMLDescription = "include-html-description"
)

Variables

This section is empty.

Functions

This section is empty.

Types

type FileFlag added in v0.16.0

type FileFlag struct{}

FileFlag is a struct used when instantiating PassedInFlags upon passing a file as parameter.

func (FileFlag) BeforeHook added in v0.16.0

func (FileFlag) BeforeHook(flags []cli.Flag) cli.BeforeFunc

This is the BeforeHook implementation for FileFlag.

func (FileFlag) ListFlags added in v0.16.0

func (FileFlag) ListFlags() *[]cli.Flag

ListFlags implementation for FileFlag.

type ParameterFlag added in v0.16.0

type ParameterFlag struct{}

ParameterFlag is a struct used when instantiating PassedInFlags upon passing release data as parameters.

func (ParameterFlag) BeforeHook added in v0.16.0

func (ParameterFlag) BeforeHook(flags []cli.Flag) cli.BeforeFunc

This is the BeforeHook implementation for ParameterFlag.

func (ParameterFlag) ListFlags added in v0.16.0

func (ParameterFlag) ListFlags() *[]cli.Flag

ListFlags implementation for ParameterFlag.

type PassedInFlags added in v0.16.0

type PassedInFlags interface {
	ListFlags() *[]cli.Flag
	BeforeHook([]cli.Flag) cli.BeforeFunc
}

PassedInFlags abstracts flags and before hook to specify in cli.Command, when creating a new release either with a file or with parameters.

Jump to